<?php

namespace Annie\Stories\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Stories\Models\SuccessStory;

class SuccessStoryPolicy
{

    /**
     * Determine if the given user can view the success_story.
     *
     * @param UserPolicy $user
     * @param SuccessStory $success_story
     *
     * @return bool
     */
    public function view(UserPolicy $user, SuccessStory $success_story)
    {
        if ($user->canDo('stories.success_story.view') && $user->isAdmin()) {
            return true;
        }

        return $success_story->user_id == user_id() && $success_story->user_type == user_type();
    }

    /**
     * Determine if the given user can create a success_story.
     *
     * @param UserPolicy $user
     * @param SuccessStory $success_story
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('stories.success_story.create');
    }

    /**
     * Determine if the given user can update the given success_story.
     *
     * @param UserPolicy $user
     * @param SuccessStory $success_story
     *
     * @return bool
     */
    public function update(UserPolicy $user, SuccessStory $success_story)
    {
        if ($user->canDo('stories.success_story.edit') && $user->isAdmin()) {
            return true;
        }

        return $success_story->user_id == user_id() && $success_story->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given success_story.
     *
     * @param UserPolicy $user
     * @param SuccessStory $success_story
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, SuccessStory $success_story)
    {
        return $success_story->user_id == user_id() && $success_story->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given success_story.
     *
     * @param UserPolicy $user
     * @param SuccessStory $success_story
     *
     * @return bool
     */
    public function verify(UserPolicy $user, SuccessStory $success_story)
    {
        if ($user->canDo('stories.success_story.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given success_story.
     *
     * @param UserPolicy $user
     * @param SuccessStory $success_story
     *
     * @return bool
     */
    public function approve(UserPolicy $user, SuccessStory $success_story)
    {
        if ($user->canDo('stories.success_story.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
